@@ -2,17 +2,16 @@
  * Copyright (c) 2011-2012 - Mauro Carvalho Chehab
  * Copyright (c) 2013 - Andre Roth <neolynx@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation version 2
- * of the License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation version 2.1 of the License.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  * Or, point your browser to http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -62,8 +61,6 @@
 #include <libdvbv5/desc_t2_delivery.h>
 #include <libdvbv5/desc_sat.h>
 
-#include <config.h>
-
 #ifdef ENABLE_NLS
 # include "gettext.h"
 # include <libintl.h>
@@ -136,16 +133,21 @@ static int is_all_bits_set(int nr, unsigned long *addr)
 }
 
 
-struct dvb_table_filter_priv {
+struct dvb_table_filter_ext_priv {
 	int last_section;
 	unsigned long is_read_bits[BITS_TO_LONGS(256)];
 
 	/* section gaps and multiple ts_id handling */
-	int first_ts_id;
+	int ext_id;
 	int first_section;
 	int done;
 };
 
+struct dvb_table_filter_priv {
+	int num_extensions;
+	struct dvb_table_filter_ext_priv *extensions;
+};
+
 static int dvb_parse_section_alloc(struct dvb_v5_fe_parms_priv *parms,
 				   struct dvb_table_filter *sect)
 {
@@ -162,9 +164,6 @@ static int dvb_parse_section_alloc(struct dvb_v5_fe_parms_priv *parms,
 		dvb_logerr(_("%s: out of memory"), __func__);
 		return -1;
 	}
-	priv->last_section = -1;
-	priv->first_section = -1;
-	priv->first_ts_id = -1;
 	sect->priv = priv;
 
 	return 0;
@@ -172,8 +171,11 @@ static int dvb_parse_section_alloc(struct dvb_v5_fe_parms_priv *parms,
 
 void dvb_table_filter_free(struct dvb_table_filter *sect)
 {
-	if (sect->priv) {
-		free(sect->priv);
+	struct dvb_table_filter_priv *priv = sect->priv;
+
+	if (priv) {
+		free (priv->extensions);
+		free(priv);
 		sect->priv = NULL;
 	}
 }
@@ -184,13 +186,15 @@ static int dvb_parse_section(struct dvb_v5_fe_parms_priv *parms,
 {
 	struct dvb_table_header h;
 	struct dvb_table_filter_priv *priv;
+	struct dvb_table_filter_ext_priv *ext;
 	unsigned char tid;
+	int i = 0, new = 0;
 
 	memcpy(&h, buf, sizeof(struct dvb_table_header));
 	dvb_table_header_init(&h);
 
 	if (parms->p.verbose)
-		dvb_log(_("%s: received table 0x%02x, TS ID 0x%04x, section %d/%d"),
+		dvb_log(_("%s: received table 0x%02x, extension ID 0x%04x, section %d/%d"),
 			__func__, h.table_id, h.id, h.section_id, h.last_section);
 
 	if (sect->tid != h.table_id) {
@@ -199,38 +203,77 @@ static int dvb_parse_section(struct dvb_v5_fe_parms_priv *parms,
 		return -1;
 	}
 	priv = sect->priv;
+	ext = priv->extensions;
 	tid = h.table_id;
 
-	if (priv->first_ts_id < 0)
-		priv->first_ts_id = h.id;
-	if (priv->first_section < 0)
-		priv->first_section = h.section_id;
-	if (priv->last_section < 0)
-		priv->last_section = h.last_section;
-	else { /* Check if the table was already parsed, but not on first pass */
-		if (!sect->allow_section_gaps && sect->ts_id == -1) {
-			if (test_bit(h.section_id, priv->is_read_bits))
+	if (!ext) {
+		ext = calloc(sizeof(struct dvb_table_filter_ext_priv), 1);
+		if (!ext) {
+			dvb_logerr(_("%s: out of memory"), __func__);
+			return -1;
+		}
+		ext->ext_id = h.id;
+		ext->first_section = h.section_id;
+		ext->last_section = h.last_section;
+		priv->extensions = ext;
+		priv->num_extensions = 1;
+		new = 1;
+	} else {
+		/* search for an specific TS ID */
+		if (sect->ts_id != -1) {
+			if (h.id != sect->ts_id)
 				return 0;
-		} else if (priv->first_ts_id == h.id && priv->first_section == h.section_id) {
-			/* tables like EIT can increment sections by gaps > 1.
-			 * in this case, reading is done when a already read
-			 * table is reached. */
-			dvb_log(_("%s: section repeated, reading done"), __func__);
-			priv->done = 1;
-			return 1;
+		}
+
+		for (i = 0; i < priv->num_extensions; i++, ext++) {
+			if (ext->ext_id == h.id)
+				break;
+		}
+		if (i == priv->num_extensions) {
+			priv->num_extensions++;
+			priv->extensions = realloc(priv->extensions, sizeof(struct dvb_table_filter_ext_priv) * (priv->num_extensions));
+			ext = priv->extensions;
+			if (!ext) {
+				dvb_logerr(_("%s: out of memory"), __func__);
+				return -1;
+			}
+			ext += i;
+			memset(ext, 0, sizeof(struct dvb_table_filter_ext_priv));
+			ext->ext_id = h.id;
+			ext->first_section = h.section_id;
+			ext->last_section = h.last_section;
+			new = 1;
 		}
 	}
 
-
-	/* search for an specific TS ID */
-	if (sect->ts_id != -1) {
-		if (h.id != sect->ts_id)
+	if (!new) { /* Check if the table was already parsed, but not on first pass */
+		if(ext->done) {
+			if (parms->p.verbose)
+				dvb_log(_("%s: extension already done, ignoring: 0x%04x"), __func__, ext->ext_id);
 			return 0;
+		}
+
+		if (!sect->allow_section_gaps && sect->ts_id == -1) {
+			if (test_bit(h.section_id, ext->is_read_bits))
+				return 0;
+		} else if (ext->ext_id == h.id && ext->first_section == h.section_id) {
+			/* tables like EIT can increment sections by gaps > 1.
+			 * in this case, reading is done when a already read
+			 * table is reached.
+			 */
+			if (parms->p.verbose)
+				dvb_log(_("%s: section repeated on table 0x%02x, extension ID 0x%04x, section %d/%d: done"),
+					__func__, h.table_id, ext->ext_id, h.section_id, h.last_section);
+
+			ext->done = 1;
+
+			goto ret;
+		}
 	}
 
 	/* handle the sections */
 	if (!sect->allow_section_gaps && sect->ts_id == -1)
-		set_bit(h.section_id, priv->is_read_bits);
+		set_bit(h.section_id, ext->is_read_bits);
 
 	if (dvb_table_initializers[tid])
 		dvb_table_initializers[tid](&parms->p, buf,
@@ -241,12 +284,27 @@ static int dvb_parse_section(struct dvb_v5_fe_parms_priv *parms,
 			   __func__, tid);
 
 	if (!sect->allow_section_gaps && sect->ts_id == -1 &&
-			is_all_bits_set(priv->last_section, priv->is_read_bits))
-		priv->done = 1;
+			is_all_bits_set(ext->last_section, ext->is_read_bits)) {
+		if (parms->p.verbose)
+			dvb_log(_("%s: table 0x%02x, extension ID 0x%04x: done"),
+				__func__, h.table_id, h.id);
+		ext->done = 1;
+	}
 
-	if (!priv->done)
+	if (!ext->done)
 		return 0;
 
+ret:
+	/* Check if all extensions are done */
+	for (ext = priv->extensions, i = 0; i < priv->num_extensions; i++, ext++) {
+		if (!ext->done) {
+			if (parms->p.verbose)
+				dvb_log(_("%s: extension not completed yet: 0x%04x"),
+						__func__, ext->ext_id);
+			return 0;
+		}
+	}
+
 	/* Section was fully parsed */
 	return 1;
 }
@@ -638,15 +696,13 @@ struct dvb_v5_descriptors *dvb_scan_transponder(struct dvb_v5_fe_parms *__p,
 int dvb_estimate_freq_shift(struct dvb_v5_fe_parms *__p)
 {
 	struct dvb_v5_fe_parms_priv *parms = (void *)__p;
-	uint32_t shift = 0, bw = 0, symbol_rate, ro;
+	uint32_t shift = 0, bw = 0, min_bw = 0, symbol_rate, ro;
 	int rolloff = 0;
 	int divisor = 100;
 
 	/* Need to handle only cable/satellite and ATSC standards */
 	switch (parms->p.current_sys) {
 	case SYS_DVBC_ANNEX_A:
-		rolloff = 115;
-		break;
 	case SYS_DVBC_ANNEX_C:
 		rolloff = 115;
 		break;
@@ -683,6 +739,15 @@ int dvb_estimate_freq_shift(struct dvb_v5_fe_parms *__p)
 		 */
 		bw = 28860 * 135 / 100;
 		break;
+	case SYS_DVBT2:
+		min_bw = 1700000;
+		break;
+	case SYS_ISDBT:
+	case SYS_DVBT:
+	case SYS_DTMB:
+		/* FIXME: does it also apply for DTMB? */
+		min_bw = 6000000;
+		break;
 	default:
 		break;
 	}
@@ -697,6 +762,8 @@ int dvb_estimate_freq_shift(struct dvb_v5_fe_parms *__p)
 	}
 	if (!bw)
 		dvb_fe_retrieve_parm(&parms->p, DTV_BANDWIDTH_HZ, &bw);
+	if (!bw)
+		bw = min_bw;
 	if (!bw)
 		dvb_log(_("Cannot calc frequency shift. " \
 			  "Either bandwidth/symbol-rate is unavailable (yet)."));
@@ -1049,9 +1116,33 @@ static void add_update_nit_dvbs(struct dvb_table_nit *nit,
 			     dvbs_dvbc_dvbs_freq_inner[d->fec]);
 	dvb_store_entry_prop(new, DTV_ROLLOFF,
 			     dvbs_rolloff[d->roll_off]);
-	if (d->roll_off != 0)
-		dvb_store_entry_prop(new, DTV_DELIVERY_SYSTEM,
-				     SYS_DVBS2);
+
+	/*
+	 * Check if the returned parameters are really DVB-S or not
+	 *
+	 * DVB-S supports only 0.35 roll-off, with QPSK and
+	 * Red-Solomon FEC 1/2, 2/3, 3/4, 5/6, 7/8. If anythign else is
+	 * reported, then it is DVB-S2.
+	 */
+
+	if ((d->roll_off != 0 && d->roll_off != ROLLOFF_35) ||
+	    (d->modulation_system != 0 && d->modulation_system != QPSK)) {
+		dvb_store_entry_prop(new, DTV_DELIVERY_SYSTEM, SYS_DVBS2);
+		return;
+	}
+
+	switch (d->fec) {
+	case FEC_NONE:
+	case FEC_AUTO:
+	case FEC_1_2:
+	case FEC_2_3:
+	case FEC_3_4:
+	case FEC_5_6:
+	case FEC_7_8:
+		return;
+	default:
+		dvb_store_entry_prop(new, DTV_DELIVERY_SYSTEM, SYS_DVBS2);
+	}
 }
 
 static void add_update_nit_isdbs(struct dvb_table_nit *nit,
