@@ -1,17 +1,16 @@
 /*
  * Copyright (c) 2011-2012 - Mauro Carvalho Chehab
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation version 2
- * of the License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation version 2.1 of the License.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  * Or, point your browser to http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -22,7 +21,6 @@
  *   c.f. EN 300 468 annex A
  */
 
-#include <config.h>
 #include <iconv.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -462,11 +460,13 @@ void dvb_parse_string(struct dvb_v5_fe_parms *parms, char **dest, char **emph,
 				emphasis = 1;
 			else if (*s == 0x87 && emphasis)
 				emphasis = 0;
-			else  if (*s >= 0x20 && (*s < 0x80 || *s > 0x9f)) {
+			else if (*s >= 0x20 && (*s < 0x80 || *s > 0x9f)) {
 				*p++ = *s;
 				if (emphasis)
 					*p2++ = *s;
 			}
+			else if (*s == 0x8a)
+				*p++ = '\n';
 		}
 		*p = '\0';
 		*p2 = '\0';
@@ -496,6 +496,8 @@ void dvb_parse_string(struct dvb_v5_fe_parms *parms, char **dest, char **emph,
 				emphasis = 1;
 			else if (code == 0xe087 && emphasis)
 				emphasis = 0;
+			else if (code == 0xe08a)
+				/* newline, append code blow */ ;
 			else if (code >= 0xe080 && code <= 0xe09f)
 				continue;
 
