@@ -22,6 +22,8 @@
 #ifndef __LIBV4LCONTROL_PRIV_H
 #define __LIBV4LCONTROL_PRIV_H
 
+#include "libv4l-plugin.h"
+
 #define V4LCONTROL_SHM_SIZE 4096
 
 #define V4LCONTROL_SUPPORTS_NEXT_CTRL 0x01
@@ -32,12 +34,14 @@ struct v4lcontrol_flags_info;
 struct v4lcontrol_data {
 	int fd;                   /* Device fd */
 	int bandwidth;            /* Connection bandwidth (0 = unknown) */
-	int flags;                /* Flags for this device */
+	unsigned int flags;       /* Flags for this device */
 	int priv_flags;           /* Internal use only flags */
-	int controls;             /* Which controls to use for this device */
+	unsigned int controls;    /* Which controls to use for this device */
 	unsigned int *shm_values; /* shared memory control value store */
 	unsigned int old_values[V4LCONTROL_COUNT]; /* for controls_changed() */
 	const struct v4lcontrol_flags_info *flags_info;
+	void *dev_ops_priv;
+	const struct libv4l_dev_ops *dev_ops;
 };
 
 struct v4lcontrol_flags_info {
