@@ -15,6 +15,7 @@
  * Free Software Foundation; version 2 of the License.
  */
 
+#include <limits.h>
 #include <string.h>
 #include <unistd.h>
 #include "helper-funcs.h"
@@ -652,7 +653,8 @@ huffmanDecoderY(int *C, int *pIn, struct comp_info *cinfo)
 
 		if (skip == -1) {
 			break;
-		} else if (skip == 0) {
+		}
+		if (skip == 0) {
 			C[i++] = coeff;
 		} else if (skip == 16) {
 			k = 16;
@@ -696,7 +698,8 @@ huffmanDecoderUV(int *C, int *pIn, struct comp_info *cinfo)
 
 		if (skip == -1) {
 			break;
-		} else if (skip == 0) {
+		}
+		if (skip == 0) {
 			C[i++] = coeff;
 		} else if (skip == 16) {
 			k = 16;
@@ -1326,8 +1329,8 @@ decompress420NoMMXOV518(unsigned char	 *pIn,
 	/* Did we decode enough? */
 	if (cinfo->bytes >= cinfo->rawLen - (897 + 64))
 		return 0;
-	else
-		return 1;
+
+	return 1;
 }
 
 /* Get quantization tables from input
@@ -1454,7 +1457,11 @@ int main(int argc, char *argv[])
 
 
 		dest_size = width * height * 3 / 2;
-		if (dest_size > sizeof(dest_buf)) {
+		if (width <= 0 || width > SHRT_MAX || height <= 0 || height > SHRT_MAX) {
+			fprintf(stderr, "%s: error: width or height out of bounds\n",
+					argv[0]);
+			dest_size = -1;
+		} else if (dest_size > sizeof(dest_buf)) {
 			fprintf(stderr, "%s: error: dest_buf too small, need: %d\n",
 					argv[0], dest_size);
 			dest_size = -1;
