@@ -25,17 +25,6 @@
 
 #define DO_SANITY_CHECKS 0
 
-static const int UVTranslate[32] = {
-	0, 1, 2, 3,
-	8, 9, 10, 11,
-	16, 17, 18, 19,
-	24, 25, 26, 27,
-	4, 5, 6, 7,
-	12, 13, 14, 15,
-	20, 21, 22, 23,
-	28, 29, 30, 31
-};
-
 static const int Y_coords_624x[128][2] = {
 	{ 0,  0}, { 1,  0}, { 2,  0}, { 3,  0}, { 4,  0}, { 5,  0}, { 6,  0}, { 7,  0},
 	{ 0,  1}, { 1,  1}, { 2,  1}, { 3,  1}, { 4,  1}, { 5,  1}, { 6,  1}, { 7,  1},
