@@ -98,13 +98,16 @@ static void log_event(struct cec_event &ev, bool wallclock)
 	case CEC_EVENT_PIN_HPD_HIGH:
 		printf("Event: HPD Pin %s\n",
 		       ev.event == CEC_EVENT_PIN_HPD_HIGH ? "High" : "Low");
-		warn("Unexpected HPD pin event!\n");
+		break;
+	case CEC_EVENT_PIN_5V_LOW:
+	case CEC_EVENT_PIN_5V_HIGH:
+		printf("Event: 5V Pin %s\n",
+		       ev.event == CEC_EVENT_PIN_5V_HIGH ? "High" : "Low");
 		break;
 	case CEC_EVENT_PIN_CEC_LOW:
 	case CEC_EVENT_PIN_CEC_HIGH:
 		printf("Event: CEC Pin %s\n",
 		       ev.event == CEC_EVENT_PIN_CEC_HIGH ? "High" : "Low");
-		warn("Unexpected CEC pin event!\n");
 		break;
 	default:
 		printf("Event: Unknown (0x%x)\n", ev.event);
