@@ -58,6 +58,7 @@
 	case V4L2_PIX_FMT_Y14P: return "14-bit Greyscale (MIPI Packed)";
 	case V4L2_PIX_FMT_Y8I: return "Interleaved 8-bit Greyscale";
 	case V4L2_PIX_FMT_Y12I: return "Interleaved 12-bit Greyscale";
+	case V4L2_PIX_FMT_Y16I: return "Interleaved 16-bit Greyscale";
 	case V4L2_PIX_FMT_Z16: return "16-bit Depth";
 	case V4L2_PIX_FMT_INZI: return "Planar 10:16 Greyscale Depth";
 	case V4L2_PIX_FMT_CNF4: return "4-bit Depth Confidence (Packed)";
@@ -91,8 +92,10 @@
 	case V4L2_PIX_FMT_YUV48_12: return "12-bit YUV 4:4:4 Packed";
 	case V4L2_PIX_FMT_NV12: return "Y/UV 4:2:0";
 	case V4L2_PIX_FMT_NV21: return "Y/VU 4:2:0";
+	case V4L2_PIX_FMT_NV15: return "10-bit Y/UV 4:2:0 (Packed)";
 	case V4L2_PIX_FMT_NV16: return "Y/UV 4:2:2";
 	case V4L2_PIX_FMT_NV61: return "Y/VU 4:2:2";
+	case V4L2_PIX_FMT_NV20: return "10-bit Y/UV 4:2:2 (Packed)";
 	case V4L2_PIX_FMT_NV24: return "Y/UV 4:4:4";
 	case V4L2_PIX_FMT_NV42: return "Y/VU 4:4:4";
 	case V4L2_PIX_FMT_P010: return "10-bit Y/UV 4:2:0";
@@ -139,6 +142,7 @@
 	case V4L2_PIX_FMT_SGBRG10DPCM8: return "8-bit Bayer GBGB/RGRG (DPCM)";
 	case V4L2_PIX_FMT_SGRBG10DPCM8: return "8-bit Bayer GRGR/BGBG (DPCM)";
 	case V4L2_PIX_FMT_SRGGB10DPCM8: return "8-bit Bayer RGRG/GBGB (DPCM)";
+	case V4L2_PIX_FMT_RAW_CRU10: return "10-bit Raw CRU Packed";
 	case V4L2_PIX_FMT_SBGGR12: return "12-bit Bayer BGBG/GRGR";
 	case V4L2_PIX_FMT_SGBRG12: return "12-bit Bayer GBGB/RGRG";
 	case V4L2_PIX_FMT_SGRBG12: return "12-bit Bayer GRGR/BGBG";
@@ -147,6 +151,7 @@
 	case V4L2_PIX_FMT_SGBRG12P: return "12-bit Bayer GBGB/RGRG Packed";
 	case V4L2_PIX_FMT_SGRBG12P: return "12-bit Bayer GRGR/BGBG Packed";
 	case V4L2_PIX_FMT_SRGGB12P: return "12-bit Bayer RGRG/GBGB Packed";
+	case V4L2_PIX_FMT_RAW_CRU12: return "12-bit Raw CRU Packed";
 	case V4L2_PIX_FMT_SBGGR14: return "14-bit Bayer BGBG/GRGR";
 	case V4L2_PIX_FMT_SGBRG14: return "14-bit Bayer GBGB/RGRG";
 	case V4L2_PIX_FMT_SGRBG14: return "14-bit Bayer GRGR/BGBG";
@@ -155,10 +160,12 @@
 	case V4L2_PIX_FMT_SGBRG14P: return "14-bit Bayer GBGB/RGRG Packed";
 	case V4L2_PIX_FMT_SGRBG14P: return "14-bit Bayer GRGR/BGBG Packed";
 	case V4L2_PIX_FMT_SRGGB14P: return "14-bit Bayer RGRG/GBGB Packed";
+	case V4L2_PIX_FMT_RAW_CRU14: return "14-bit Raw CRU Packed";
 	case V4L2_PIX_FMT_SBGGR16: return "16-bit Bayer BGBG/GRGR";
 	case V4L2_PIX_FMT_SGBRG16: return "16-bit Bayer GBGB/RGRG";
 	case V4L2_PIX_FMT_SGRBG16: return "16-bit Bayer GRGR/BGBG";
 	case V4L2_PIX_FMT_SRGGB16: return "16-bit Bayer RGRG/GBGB";
+	case V4L2_PIX_FMT_RAW_CRU20: return "14-bit Raw CRU Packed";
 	case V4L2_PIX_FMT_SN9C20X_I420: return "GSPCA SN9C20X I420";
 	case V4L2_PIX_FMT_SPCA501: return "GSPCA SPCA501";
 	case V4L2_PIX_FMT_SPCA505: return "GSPCA SPCA505";
@@ -185,10 +192,14 @@
 	case V4L2_META_FMT_VSP1_HGO: return "R-Car VSP1 1-D Histogram";
 	case V4L2_META_FMT_VSP1_HGT: return "R-Car VSP1 2-D Histogram";
 	case V4L2_META_FMT_UVC: return "UVC Payload Header Metadata";
+	case V4L2_META_FMT_UVC_MSXU_1_5: return "UVC MSXU Metadata";
 	case V4L2_META_FMT_D4XX: return "Intel D4xx UVC Metadata";
 	case V4L2_META_FMT_VIVID: return "Vivid Metadata";
 	case V4L2_META_FMT_RK_ISP1_PARAMS: return "Rockchip ISP1 3A Parameters";
 	case V4L2_META_FMT_RK_ISP1_STAT_3A: return "Rockchip ISP1 3A Statistics";
+	case V4L2_META_FMT_RK_ISP1_EXT_PARAMS: return "Rockchip ISP1 Ext 3A Params";
+	case V4L2_META_FMT_C3ISP_PARAMS: return "Amlogic C3 ISP Parameters";
+	case V4L2_META_FMT_C3ISP_STATS: return "Amlogic C3 ISP Statistics";
 	case V4L2_PIX_FMT_NV12_8L128: return "NV12 (8x128 Linear)";
 	case V4L2_PIX_FMT_NV12M_8L128: return "NV12M (8x128 Linear)";
 	case V4L2_PIX_FMT_NV12_10BE_8L128: return "10-bit NV12 (8x128 Linear, BE)";
@@ -197,6 +208,8 @@
 	case V4L2_PIX_FMT_Y212: return "12-bit YUYV Packed";
 	case V4L2_PIX_FMT_Y216: return "16-bit YUYV Packed";
 	case V4L2_META_FMT_RPI_BE_CFG: return "RPi PiSP BE Config format";
+	case V4L2_META_FMT_RPI_FE_CFG: return "RPi PiSP FE Config format";
+	case V4L2_META_FMT_RPI_FE_STATS: return "RPi PiSP FE Statistics format";
 	case V4L2_PIX_FMT_MJPEG: return "Motion-JPEG";
 	case V4L2_PIX_FMT_JPEG: return "JFIF JPEG";
 	case V4L2_PIX_FMT_DV: return "1394";
