@@ -273,7 +273,6 @@ static const struct argp_option options[] = {
 	{"delay",	'D',	N_("DELAY"),	0,	N_("Sets the delay before repeating a keystroke"), 0},
 	{"period",	'P',	N_("PERIOD"),	0,	N_("Sets the period to repeat a keystroke"), 0},
 	{"auto-load",	'a',	N_("CFGFILE"),	0,	N_("Auto-load keymaps, based on a configuration file. Only works with --sysdev."), 0},
-	{"test-keymap",	1,	N_("KEYMAP"),	0,	N_("Test if keymap is valid"), 0},
 	{"help",        '?',	0,		0,	N_("Give this help list"), -1},
 	{"usage",	-3,	0,		0,	N_("Give a short usage message")},
 	{"version",	'V',	0,		0,	N_("Print program version"), -1},
@@ -290,7 +289,6 @@ int debug = 0;
 static int test = 0;
 static int delay = -1;
 static int period = -1;
-static int test_keymap = 0;
 static enum sysfs_protocols ch_proto = 0;
 
 struct bpf_protocol {
@@ -697,16 +695,6 @@ static error_t parse_opt(int k, char *arg, struct argp_state *state)
 			p = strtok(NULL, ":=");
 		} while (p);
 		break;
-	case 1:
-		test_keymap++;
-		struct keymap *map ;
-
-		rc = parse_keymap(arg, &map, debug);
-		if (rc)
-			argp_error(state, _("Failed to read table file %s"), arg);
-		add_keymap(map, arg);
-		free_keymap(map);
-		break;
 	case '?':
 		argp_state_help(state, state->out_stream,
 				ARGP_HELP_SHORT_USAGE | ARGP_HELP_LONG
@@ -1714,7 +1702,7 @@ static int set_rate(int fd, unsigned int delay, unsigned int period)
 		return -1;
 	}
 
-	printf(_("Changed Repeat delay to %d ms and repeat period to %d ms\n"), delay, period);
+	fprintf(stderr, _("Changed Repeat delay to %d ms and repeat period to %d ms\n"), delay, period);
 	return 0;
 }
 
@@ -1728,7 +1716,7 @@ static int get_rate(int fd, unsigned int *delay, unsigned int *period)
 	}
 	*delay = rep[0];
 	*period = rep[1];
-	printf(_("Repeat delay: %d ms, repeat period: %d ms\n"), *delay, *period);
+	fprintf(stderr, _("Repeat delay: %d ms, repeat period: %d ms\n"), *delay, *period);
 	return 0;
 }
 
@@ -1736,7 +1724,7 @@ static void show_evdev_attribs(int fd)
 {
 	unsigned int delay, period;
 
-	printf("\t");
+	fprintf(stderr, "\t");
 	get_rate(fd, &delay, &period);
 }
 
@@ -1839,10 +1827,10 @@ static void show_bpf(const char *lirc_name)
 		goto error;
 	}
 
-	printf(_("\tAttached BPF protocols: "));
+	fprintf(stderr, _("\tAttached BPF protocols: "));
 	for (i=0; i<count; i++) {
 		if (i)
-			printf(" ");
+			fprintf(stderr, " ");
 		prog_fd = bpf_prog_get_fd_by_id(prog_ids[i]);
 		if (prog_fd != -1) {
 			struct bpf_prog_info info = {};
@@ -1851,16 +1839,16 @@ static void show_bpf(const char *lirc_name)
 			ret = bpf_obj_get_info_by_fd(prog_fd, &info, &info_len);
 			close(prog_fd);
 			if (!ret && info.name[0]) {
-				printf("%s", info.name);
+				fprintf(stderr, "%s", info.name);
 				continue;
 			}
 		}
-		printf("%d", prog_ids[i]);
+		fprintf(stderr, "%d", prog_ids[i]);
 	}
-	printf(_("\n"));
+	fprintf(stderr, _("\n"));
 	return;
 error:
-	printf(_("\tAttached BPF protocols: %m\n"));
+	fprintf(stderr, _("\tAttached BPF protocols: %m\n"));
 }
 
 static void clear_bpf(const char *lirc_name)
@@ -1899,13 +1887,13 @@ static void clear_bpf(const char *lirc_name)
 				prog_ids[i]);
 		prog_fd = bpf_prog_get_fd_by_id(prog_ids[i]);
 		if (prog_fd == -1) {
-			printf(_("Failed to get BPF prog id %u: %m\n"),
+			fprintf(stderr, _("error: failed to get BPF prog id %u: %m\n"),
 			       prog_ids[i]);
 			continue;
 		}
 		ret = bpf_prog_detach2(prog_fd, fd, BPF_LIRC_MODE2);
 		if (ret)
-			printf(("Failed to detach BPF prog id %u: %m\n"),
+			fprintf(stderr, _("error: failed to detach BPF prog id %u: %m\n"),
 			       prog_ids[i]);
 		close(prog_fd);
 	}
@@ -1963,7 +1951,7 @@ static int show_sysfs_attribs(struct rc_device *rc_dev, char *name)
 				show_evdev_attribs(fd);
 				close(fd);
 			} else {
-				printf(_("\tExtra capabilities: <access denied>\n"));
+				fprintf(stderr, _("\tExtra capabilities: <access denied>\n"));
 			}
 		}
 	}
@@ -2070,9 +2058,6 @@ int main(int argc, char *argv[])
 
 	argp_parse(&argp, argc, argv, ARGP_NO_HELP, 0, 0);
 
-	if (test_keymap)
-		return 0;
-
 	/* Just list all devices */
 	if (!clear && !readtable && !keytable && !ch_proto && !cfg.next && !test && delay < 0 && period < 0 && !bpf_protocol) {
 		if (show_sysfs_attribs(&rc_dev, devclass))
@@ -2084,7 +2069,7 @@ int main(int argc, char *argv[])
 	if (!devclass)
 		devclass = "rc0";
 
-	if (cfg.next && (clear || keytable || ch_proto)) {
+	if (cfg.next && (clear || keytable || ch_proto || bpf_protocol || test)) {
 		fprintf (stderr, _("Auto-mode can be used only with --read, --verbose and --sysdev options\n"));
 		return -1;
 	}
