@@ -517,6 +517,10 @@ struct parse_event key_events[] = {
 	{"BTN_DPAD_DOWN", 0x221},
 	{"BTN_DPAD_LEFT", 0x222},
 	{"BTN_DPAD_RIGHT", 0x223},
+	{"BTN_GRIPL", 0x224},
+	{"BTN_GRIPR", 0x225},
+	{"BTN_GRIPL2", 0x226},
+	{"BTN_GRIPR2", 0x227},
 	{"KEY_ALS_TOGGLE", 0x230},
 	{"KEY_ROTATE_LOCK_TOGGLE", 0x231},
 	{"KEY_REFRESH_RATE_TOGGLE", 0x232},
@@ -621,6 +625,7 @@ struct parse_event key_events[] = {
 	{"KEY_KBD_LCD_MENU3", 0x2ba},
 	{"KEY_KBD_LCD_MENU4", 0x2bb},
 	{"KEY_KBD_LCD_MENU5", 0x2bc},
+	{"KEY_PERFORMANCE", 0x2bd},
 	{"BTN_TRIGGER_HAPPY", 0x2c0},
 	{"BTN_TRIGGER_HAPPY1", 0x2c0},
 	{"BTN_TRIGGER_HAPPY2", 0x2c1},
