@@ -56,7 +56,7 @@ void meta_cmd(int ch, char *optarg)
 			vfmt.fmt.meta.dataformat = v4l2_fourcc(optarg[0],
 					optarg[1], optarg[2], optarg[3]);
 		} else {
-			vfmt.fmt.meta.dataformat = strtol(optarg, nullptr, 0);
+			vfmt.fmt.meta.dataformat = strtoul(optarg, nullptr, 0);
 		}
 		break;
 	case OptListMetaFormats:
