@@ -5,18 +5,25 @@ static __u32 width, height, pixfmt, field, colorspace, xfer_func, ycbcr, quantiz
 static __u32 bytesperline[VIDEO_MAX_PLANES];
 static __u32 sizeimage[VIDEO_MAX_PLANES];
 static unsigned mbus_code_out;
+static bool enum_all;
 
 void vidout_usage()
 {
 	printf("\nVideo Output Formats options:\n"
-	       "  --list-formats-out [<mbus_code>] display supported video output formats.\n"
+	       "  --list-formats-out [<mbus_code>|all] display supported video output formats.\n"
 	       "		     <mbus_code> is an optional media bus code, if the device has\n"
 	       "		     capability V4L2_CAP_IO_MC then only formats that support this\n"
-	       "		     media bus code are listed [VIDIOC_ENUM_FMT]\n"
-	       "  --list-formats-out-ext [<mbus_code>] display supported video output formats including\n"
+	       "		     media bus code are listed.\n"
+	       "		     When 'all' is specified it enumerates all pixel formats if\n"
+	       "		     V4L2_FMTDESC_FLAG_ENUM_ALL flag is supported by the driver.\n"
+	       "		     [VIDIOC_ENUM_FMT]\n"
+	       "  --list-formats-out-ext [<mbus_code>|all] display supported video output formats including\n"
 	       "		     frame sizes and intervals. <mbus_code> is an optional media bus code,\n"
 	       "		     if the device has capability V4L2_CAP_IO_MC then only formats that\n"
-	       "		     support this media bus code are listed [VIDIOC_ENUM_FMT]\n"
+	       "		     support this media bus code are listed\n"
+	       "		     When 'all' is specified it enumerates all pixel formats if\n"
+	       "		     V4L2_FMTDESC_FLAG_ENUM_ALL flag is supported by the driver.\n"
+	       "		     [VIDIOC_ENUM_FMT]\n"
 	       "  --list-fields-out  list supported fields for the current output format\n"
 	       "  -X, --get-fmt-video-out\n"
 	       "     		     query the video output format [VIDIOC_G_FMT]\n"
@@ -93,8 +100,12 @@ void vidout_cmd(int ch, char *optarg)
 		break;
 	case OptListOutFormats:
 	case OptListOutFormatsExt:
-		if (optarg)
-			mbus_code_out = strtoul(optarg, nullptr, 0);
+		if (optarg) {
+			if (strstr(optarg , "all"))
+				enum_all = true;
+			else
+				mbus_code_out = strtoul(optarg, nullptr, 0);
+		}
 		break;
 	}
 }
@@ -226,12 +237,12 @@ void vidout_list(cv4l_fd &fd)
 {
 	if (options[OptListOutFormats]) {
 		printf("ioctl: VIDIOC_ENUM_FMT\n");
-		print_video_formats(fd, vidout_buftype, mbus_code_out);
+		print_video_formats(fd, vidout_buftype, mbus_code_out, enum_all);
 	}
 
 	if (options[OptListOutFormatsExt]) {
 		printf("ioctl: VIDIOC_ENUM_FMT\n");
-		print_video_formats_ext(fd, vidout_buftype, mbus_code_out);
+		print_video_formats_ext(fd, vidout_buftype, mbus_code_out, enum_all);
 	}
 
 	if (options[OptListOutFields]) {
