@@ -3,7 +3,7 @@
 
     Cleanup and VBI and audio in/out options, introduction in v4l-dvb,
     support for most new APIs since 2006.
-    Copyright (C) 2004, 2006, 2007  Hans Verkuil <hverkuil@xs4all.nl>
+    Copyright (C) 2004, 2006, 2007  Hans Verkuil <hverkuil@kernel.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -813,7 +813,7 @@ int parse_fmt(char *optarg, __u32 &width, __u32 &height, __u32 &pixelformat,
 				if (be_pixfmt)
 					pixelformat |= 1U << 31;
 			} else if (isdigit(value[0])) {
-				pixelformat = strtol(value, nullptr, 0);
+				pixelformat = strtoul(value, nullptr, 0);
 			} else {
 				fprintf(stderr, "The pixelformat '%s' is invalid\n", value);
 				std::exit(EXIT_FAILURE);
