@@ -151,7 +151,8 @@ sub clean_up_line {
 	$line =~ s/^\s+//; # remove leading whitespace
 	$line =~ s/.*\# define.*//; # zero out line if it has defines inside a structure (e.g. v4l2_jpegcompression)
 	$line =~ s/^\s*\/?\s?\*.*//; # zero out line if it has comments where the line starts with start with /* / * or just *
-	$line =~ s/\s*\/\*.*//; # remove comments at the end of a line following a member
+	$line =~ s/\s*\/\*.*//; # remove comments /* */ at the end of a line following a member
+	$line =~ s/\s*\/\/.*//; # remove comments // at the end of a line following a member
 	$line =~ s/\*\/$//; # zero out line if it has comments that begin without any slashs or asterisks but end with */
 	# zero out lines that don't have a ; or { because they are comments but without any identifying slashes or asteriks
 	if ($line !~ /.*[\;|\{].*/) {
@@ -865,29 +866,29 @@ sub do_open($$) {
 
 $fh_trace_cpp = do_open("trace", "trace-gen.cpp");
 printf $fh_trace_cpp "/* SPDX-License-Identifier: GPL-2.0-only */\n/*\n * Copyright 2022 Collabora Ltd.\n";
-printf $fh_trace_cpp " *\n * AUTOMATICALLY GENERATED BY \'%s\' DO NOT EDIT\n */\n\n", __FILE__;
+printf $fh_trace_cpp " *\n * AUTOMATICALLY GENERATED BY v4l2-tracer-gen.pl DO NOT EDIT\n */\n\n";
 printf $fh_trace_cpp "#include \"v4l2-tracer-common.h\"\n\n";
 
 $fh_trace_h = do_open("trace", "trace-gen.h");
 printf $fh_trace_h "/* SPDX-License-Identifier: GPL-2.0-only */\n/*\n * Copyright 2022 Collabora Ltd.\n";
-printf $fh_trace_h " *\n * AUTOMATICALLY GENERATED BY \'%s\' DO NOT EDIT\n */\n\n", __FILE__;
+printf $fh_trace_h " *\n * AUTOMATICALLY GENERATED BY v4l2-tracer-gen.pl DO NOT EDIT\n */\n\n";
 printf $fh_trace_h "\#ifndef TRACE_GEN_H\n";
 printf $fh_trace_h "\#define TRACE_GEN_H\n\n";
 
 $fh_retrace_cpp = do_open("retrace", "retrace-gen.cpp");
 printf $fh_retrace_cpp "/* SPDX-License-Identifier: GPL-2.0-only */\n/*\n * Copyright 2022 Collabora Ltd.\n";
-printf $fh_retrace_cpp " *\n * AUTOMATICALLY GENERATED BY \'%s\' DO NOT EDIT\n */\n\n", __FILE__;
+printf $fh_retrace_cpp " *\n * AUTOMATICALLY GENERATED BY v4l2-tracer-gen.pl DO NOT EDIT\n */\n\n";
 printf $fh_retrace_cpp "#include \"v4l2-tracer-common.h\"\n\n";
 
 $fh_retrace_h = do_open("retrace", "retrace-gen.h");
 printf $fh_retrace_h "/* SPDX-License-Identifier: GPL-2.0-only */\n/*\n * Copyright 2022 Collabora Ltd.\n";
-printf $fh_retrace_h " *\n * AUTOMATICALLY GENERATED BY \'%s\' DO NOT EDIT\n */\n\n", __FILE__;
+printf $fh_retrace_h " *\n * AUTOMATICALLY GENERATED BY v4l2-tracer-gen.pl DO NOT EDIT\n */\n\n";
 printf $fh_retrace_h "\#ifndef RETRACE_GEN_H\n";
 printf $fh_retrace_h "\#define RETRACE_GEN_H\n\n";
 
 $fh_common_info_h = do_open("common", "v4l2-tracer-info-gen.h");
 printf $fh_common_info_h "/* SPDX-License-Identifier: GPL-2.0-only */\n/*\n * Copyright 2022 Collabora Ltd.\n";
-printf $fh_common_info_h " *\n * AUTOMATICALLY GENERATED BY \'%s\' DO NOT EDIT\n */\n\n", __FILE__;
+printf $fh_common_info_h " *\n * AUTOMATICALLY GENERATED BY v4l2-tracer-gen.pl DO NOT EDIT\n */\n\n";
 printf $fh_common_info_h "\#ifndef V4L2_TRACER_INFO_GEN_H\n";
 printf $fh_common_info_h "\#define V4L2_TRACER_INFO_GEN_H\n\n";
 printf $fh_common_info_h "#include \"v4l2-tracer-common.h\"\n\n";
@@ -942,7 +943,7 @@ while (<>) {
 	}
 	if (grep {/^#define V4L2_BUF_CAP_SUPPORTS_MMAP\s+/} $_) {
 		printf $fh_common_info_h "constexpr flag_def v4l2_buf_cap_flag_def[] = {\n";
-		flag_def_gen("V4L2_BUF_CAP_SUPPORTS_MMAP_CACHE_HINTS");
+		flag_def_gen("V4L2_BUF_CAP_SUPPORTS_MAX_NUM_BUFFERS");
 		next;
 	}
 	if (grep {/^#define V4L2_STD_PAL_B\s+/} $_) {
@@ -1067,6 +1068,8 @@ printf $fh_common_info_h "\t{ -1, \"\" }\n};\n";
 
 printf $fh_trace_h "\n#endif\n";
 close $fh_trace_h;
+# Delete the last of two new lines to avoid a whitespace error
+truncate($fh_trace_cpp, tell($fh_trace_cpp) - 1);
 close $fh_trace_cpp;
 
 printf $fh_retrace_h "\n#endif\n";
